@@ -29,6 +29,7 @@
 *  History:
 *     2012-02-08 (TIMJ):
 *        Initial version.
+*        Adapted with permission from the Fortran SLALIB library.
 *     2012-04-13 (DSB):
 *        Added PAL__DR2H and PAL__DR2S
 *     {enter_further_changes_here}
@@ -64,8 +65,11 @@ static const double PAL__DPI = 3.14159265358979323846264338327950288419716939937
 /* 2Pi */
 static const double PAL__D2PI = 6.2831853071795864769252867665590057683943387987502;
 
+/* pi/2:  90 degrees in radians */
+static const double PAL__DPIBY2 = 1.5707963267948966192313216916397514420985846996876;
+
 /* pi/180:  degrees to radians */
-static const double  PAL__DD2R = 0.017453292519943295769236907684886127134428718885417;
+static const double PAL__DD2R = 0.017453292519943295769236907684886127134428718885417;
 
 /* Radians to arcseconds */
 static const double PAL__DR2AS = 2.0626480624709635515647335733077861319665970087963e5;
@@ -73,12 +77,21 @@ static const double PAL__DR2AS = 2.062648062470963551564733573307786131966597008
 /* Arcseconds to radians */
 static const double PAL__DAS2R = 4.8481368110953599358991410235794797595635330237270e-6;
 
+/* Radians to degrees */
+static const double PAL__DR2D = 57.295779513082320876798154814105170332405472466564;
+
+/* Hours to radians */
+static const double PAL__DH2R = 0.26179938779914943653855361527329190701643078328126;
+
 /* Radians to hours */
 static const double PAL__DR2H = 3.8197186342054880584532103209403446888270314977709;
 
 /* Radians to seconds of time */
 static const double PAL__DR2S = 1.3750987083139757010431557155385240879777313391975e4;
 
+/* Seconds of time to radians */
+static const double PAL__DS2R = 7.272205216643039903848712e-5;
+
 /* Start of SLA modified Julian date epoch */
 static const double PAL__MJD0 = 2400000.5;
 
@@ -103,11 +116,17 @@ static const double PAL__SR = 7.2921150e-5;
 /*  Gaussian gravitational constant (exact) */
 static const double PAL__GCON = 0.01720209895;
 
+/* DINR(A) - truncate to nearest whole number towards zero (double) */
+#define DINT(A) ((A)<0.0?ceil(A):floor(A))
+
 /* DNINT(A) - round to nearest whole number (double) */
 #define DNINT(A) ((A)<0.0?ceil((A)-0.5):floor((A)+0.5))
 
 /* DMAX(A,B) - return maximum value - evaluates arguments multiple times */
-#define DMAX(A,B) (A > B ? A : B )
+#define DMAX(A,B) ((A) > (B) ? (A) : (B) )
+
+/* DMIN(A,B) - return minimum value - evaluates arguments multiple times */
+#define DMIN(A,B) ((A) < (B) ? (A) : (B) )
 
 /* We actually prefer to use C99 copysign() but we define this here as a backup
    but it will not detect -0.0 so is not useful for palDfltin. */
